@@ -79,8 +79,8 @@ class Arc(Hold):
                 value[each[0]] = int(each[1])
             self.__dict__[key] = sorted(value)
         elif key == 'color':
-            if not 0 <= value <= 2:
-                raise AffNoteValueError('invalid value {} for attribute "color" (only accept 0~2)'.format(value))
+            if not 0 <= value <= 3:
+                raise AffNoteValueError('invalid value {} for attribute "color" (only accept 0~3)'.format(value))
         elif key == 'slideeasing':
             if isinstance(value, str):
                 exvalid = validstrings.slideeasinglist + validstrings.slideeasingexlist
@@ -188,11 +188,11 @@ class Arc(Hold):
                 self.skynote[each[0]] += value
         return self
         
-    def align(self, bpm: float, error: int = 3, lcd = 96):
-        super(Arc, self).align(bpm, error, lcd)
+    def align(self, bpm: float, error: int = 3, lcm = 96):
+        super(Arc, self).align(bpm, error, lcm)
         if self.skynote:
             for each in enumerate(self.skynote):
-                self.skynote[each[0]] = time_align(self.skynote[each[0]], bpm, error, lcd)
+                self.skynote[each[0]] = time_align(self.skynote[each[0]], bpm, error, lcm)
         return self
     
     def transfer(self, x_value: float, y_value: float):
